@@ -43,11 +43,11 @@
 #include "widgets/systemtray.h"
 #include "mainactions.h"
 
-#include "misc/config.h"
+#include "misc/kftpconfig.h"
 #include "misc/filter.h"
 
-#include <ntqdir.h>
-#include <ntqobjectlist.h>
+#include <tqdir.h>
+#include <tqobjectlist.h>
 
 #include <tdemessagebox.h>
 #include <tdelocale.h>
